# SDLE FAIR Package: Centralized Entity Mapping & Extraction Nexus for Triples and Ontologies (CEMENTO)

**Description:**

This package is part of the larger SDLE FAIR application suite that features tools to create scientific ontologies faster and more efficiently. This package can provide OOP interfaces for drawing and reading ontology diagrams made using draw.io. The code is able to generate a list of relationship triples that are used to store and construct ontology diagrams.

## Installation

To install this particular package, download the latest wheel file available online (link not live yet), and the use pip in the following manner:

```{bash}
python -m build
pip install dist/cemento-0.3.0-py3-none-any.whl
```

## Usage

One can refer to the examples folder for sample implementations of basic read and write operations with draw.io diagrams.

## License

[Open Source Initiative](https://opensource.org/licenses)

## Contact Information
If you have any questions or need further assistance, feel free to contact us at:

Email: 
[gop2@case.edu](Gabriel Obsequio Ponon)